package cn.com.ty.lift.business.project.controller;

import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.library.dao.entity.model.request.SelectBatchPlatformCompanyRequest;
import cn.com.ty.lift.business.library.service.PlatformCompanyLiftRelevanceService;
import cn.com.ty.lift.business.project.dao.entity.Project;
import cn.com.ty.lift.business.project.dao.entity.ProjectHistory;
import cn.com.ty.lift.business.project.dao.entity.ProjectUser;
import cn.com.ty.lift.business.project.dao.entity.model.request.*;
import cn.com.ty.lift.business.project.dao.entity.model.response.ProjectRelevanceResponse;
import cn.com.ty.lift.business.project.dao.entity.model.response.ProjectResponse;
import cn.com.ty.lift.business.project.service.ProjectLiftRelevanceService;
import cn.com.ty.lift.business.project.service.ProjectService;
import cn.com.ty.lift.business.project.service.ProjectUserService;
import cn.com.ty.lift.common.base.ExportRequest;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * @author bieao
 * @date 2019/11/28
 * @description 项目管理控制层
 */
@RestController
@RequestMapping("project")
public class ProjectController {

    @Resource
    private ProjectService projectService;

    @Resource
    private ProjectUserService projectUserService;

    @Resource
    private PlatformCompanyLiftRelevanceService platformCompanyLiftRelevanceService;

    @Resource
    private ProjectLiftRelevanceService projectLiftRelevanceService;

    /**
     * @param request 项目列表查询条件
     * @return RestResponse 项目分页列表结果
     * @description 查询项目列表
     * @date 2019/11/28 4:18 PM
     */
    @PostMapping("list")
    public RestResponse list(@Valid @RequestBody ProjectRequest request) {
        IPage<ProjectResponse> page =  projectService.list(request);
        if (CollUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 公司项目查询条件
     * @return RestResponse 公司项目分页列表结果
     * @description 查询公司项目列表
     * @date 2019/12/9 10:32 AM
     */
    @PostMapping("companyList")
    public RestResponse companyList(@Valid @RequestBody ProjectCompanyRequest request) {
        IPage<ProjectResponse> page = projectService.companyList(request);
        if (CollUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 项目操作记录查询条件
     * @return RestResponse 项目操作记录分页列表结果
     * @description 查询项目操作记录列表
     * @date 2019/12/2 11:41 AM
     */
    @PostMapping("history/list")
    public RestResponse historyList(@RequestBody ProjectRequest request) {
        IPage<ProjectHistory> page = projectService.historyList(request);
        if (CollUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request projectId 项目ID
     * @return RestResponse userList项目组成员列表
     * @description 查询项目组成员
     * @date 2019/12/13 2:40 PM
     */
    @PostMapping("userList")
    public RestResponse userList(@Valid @RequestBody ProjectDetailRequest request) {
        List<ProjectUser> userList = projectUserService.userList(request);
        if (CollUtil.isEmpty(userList)) {
            return RestResponse.success();
        }
        return RestResponse.success(userList, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request regionId 区域id
     * @return RestResponse userList项目组成员列表
     * @description 查询项目id和名称列表
     * @date 2019/12/13 2:40 PM
     */
    @PostMapping("projectIDList")
    public RestResponse projectIDList(@RequestBody ProjectRegionRequest request) {
        List<Map<String, Object>> projectIDList = projectService.projectIDList(request);
        if (CollUtil.isEmpty(projectIDList)) {
            return RestResponse.success();
        }
        return RestResponse.success(projectIDList, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 项目id
     * @return RestResponse 项目详情
     * @description 查询项目详情
     * @date 2019/12/6 10:51 AM
     */
    @PostMapping("detail")
    public RestResponse detail(@Valid @RequestBody ProjectDetailRequest request) {
        Project project = projectService.detail(request.getId());
        if (ObjectUtil.isEmpty(project)) {
            return RestResponse.success();
        }
        return RestResponse.success(project, MessageUtils.get("msg.query.detail.success"));
    }

    /**
     * @param request 新增项目数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 新增项目
     * @date 2019/11/28 4:19 PM
     */
    @PostMapping("add")
    public RestResponse add(@Valid @RequestBody ProjectExtensionRequest request) {
        return projectService.add(request);
    }

    /**
     * @param projectUser 新增维保工数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 新增维保工
     * @date 2019/12/4 4:44 PM
     */
    @PostMapping("worker/add")
    public RestResponse add(@RequestBody ProjectUser projectUser) {
        Integer result = projectUserService.add(projectUser);
        if (result > 0) {
            return RestResponse.success(ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.add.success"));
        }
        return RestResponse.fail(MessageUtils.get("msg.add.fail"));
    }

    /**
     * @param project 修改项目数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 修改项目
     * @date 2019/11/28 4:19 PM
     */
    @PostMapping("modify")
    public RestResponse modify(@RequestBody Project project) {
        Integer result = projectService.modify(project);
        if (result > 0) {
            return RestResponse.success(result, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.modify.success"));
        }
        return RestResponse.fail(MessageUtils.get("msg.modify.fail"));
    }

    /**
     * @param request liftIdList 电梯id列表
     * @param request projectId 项目id
     * @param request operate 操作 1:恢复服务，2:停止服务，3:继续服务
     * @return 1.成功, 0.失败, 消息描述
     * @description 服务操作
     * @date 2019/12/10 5:42 PM
     */
    @PostMapping("serviceOperate")
    public RestResponse serviceOperate(@RequestBody SelectBatchPlatformCompanyRequest request) {
        return platformCompanyLiftRelevanceService.serviceOperate(request);
    }

    /**
     * @param request projectId 项目id
     * @return 1.成功, 0.失败, 消息描述
     * @description 项目锁定、解锁
     * @date 2019/11/27 10:03 AM
     */
    @PostMapping("lockOrUnlock")
    public RestResponse lockOrUnlock(@Valid @RequestBody ProjectLockRequest request) {
        return projectLiftRelevanceService.projectLockOrUnLock(request);
    }

    /**
     * @param request 用户id
     * @return 1.成功, 0.失败, 消息描述
     * @description 查询用户下的关联项目和电梯信息
     * @date 2019/12/26 4:27 PM
     */
    @PostMapping("relevance/list")
    public RestResponse relevanceList(@RequestBody ProjectLiftRelevanceRequest request) {
        IPage<ProjectRelevanceResponse> page = projectLiftRelevanceService.relevanceList(request);
        if (CollUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 导出项目数据列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 导出项目
     * @date 2019/11/28 4:19 PM
     */
    @PostMapping("export")
    public void export(@RequestBody ExportRequest request) {
        projectService.export(request);
    }
}